System.register('myBundle', ['highcharts'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('Highcharts', module);
		}],
		execute: (function () {



		})
	};
}));
